@@ -1,12 +1,11 @@
 var 2Dfold_8h =
 [
-    [ "vrna_sol_TwoD_t", "group__kl__neighborhood__mfe.html#ga6a81a58268d250309712549a3fa0aab2", null ],
-    [ "TwoDfold_vars", "group__kl__neighborhood__mfe.html#gaf4f514010a14f9d59d850742b3e96954", null ],
+    [ "vrna_sol_TwoD_t", "group__kl__neighborhood__mfe.html#ga2ab9478dc2f8d94ab38ca8b3308d1c1e", null ],
+    [ "TwoDfold_vars", "group__kl__neighborhood__mfe.html#gad18b01ec62ac426567b9a235fe754548", null ],
     [ "vrna_mfe_TwoD", "group__kl__neighborhood__mfe.html#ga243c288b463147352829df04de6a2f77", null ],
     [ "vrna_backtrack5_TwoD", "group__kl__neighborhood__mfe.html#ga15a96fc96f4f4c2e01a11b3e17d1ef43", null ],
     [ "get_TwoDfold_variables", "group__kl__neighborhood__mfe.html#gac9284f132cf0eaa0a2f43590eda05488", null ],
     [ "destroy_TwoDfold_variables", "group__kl__neighborhood__mfe.html#ga05bf4f31d216b1b160fd2d3d68e9b487", null ],
     [ "TwoDfoldList", "group__kl__neighborhood__mfe.html#ga7fc5e3e92fe97914ca4eccd33c01c2a7", null ],
-    [ "TwoDfold_backtrack_f5", "group__kl__neighborhood__mfe.html#gaf4dc05bf8fc1ea53acd7aeb798ba80c2", null ],
-    [ "TwoDfold", "group__kl__neighborhood__mfe.html#ga9827e1deba983a95d0509d36b61fb0e2", null ]
+    [ "TwoDfold_backtrack_f5", "group__kl__neighborhood__mfe.html#gaf4dc05bf8fc1ea53acd7aeb798ba80c2", null ]
 ];
\ No newline at end of file
