@@ -12,6 +12,5 @@ var fold_8h =
     [ "export_circfold_arrays_par", "group__mfe__global__deprecated.html#ga004bb901e7fd2f8d5ae68f9530318ce1", null ],
     [ "LoopEnergy", "group__mfe__global__deprecated.html#ga2163034a25c6115d894b199e97e03f6c", null ],
     [ "HairpinE", "group__mfe__global__deprecated.html#gab327ce11972f5ac069d52c8dedfdb700", null ],
-    [ "initialize_fold", "group__mfe__global__deprecated.html#gac3f0a28d9cb609d388b155445073fd20", null ],
-    [ "backtrack_fold_from_pair", "group__mfe__global__deprecated.html#ga33c35bfd60df9d7a97aec72b887e6858", null ]
+    [ "initialize_fold", "group__mfe__global__deprecated.html#gac3f0a28d9cb609d388b155445073fd20", null ]
 ];
\ No newline at end of file
