@@ -15,13 +15,13 @@ var group__utils =
     [ "combinatorics.h", "combinatorics_8h.html", null ],
     [ "commands.h", "commands_8h.html", null ],
     [ "sequence.h", "sequence_8h.html", null ],
-    [ "units.h", "units_8h.html", null ],
     [ "file_formats_msa.h", "io_2file__formats__msa_8h.html", null ],
     [ "utils.h", "io_2utils_8h.html", null ],
     [ "utils.h", "plotting_2utils_8h.html", null ],
     [ "alignments.h", "utils_2alignments_8h.html", null ],
     [ "basic.h", "utils_2basic_8h.html", null ],
     [ "strings.h", "strings_8h.html", null ],
+    [ "units.h", "utils_2units_8h.html", null ],
     [ "BoyerMoore.h", "BoyerMoore_8h.html", null ],
     [ "char_stream.h", "datastructures_2char__stream_8h.html", null ],
     [ "stream_output.h", "datastructures_2stream__output_8h.html", null ],
