@@ -15,21 +15,21 @@ var NAVTREEINDEX0 =
 "2Dpfold_8h_source.html":[17,0,0,10],
 "BoyerMoore_8h.html":[17,0,0,7,0],
 "BoyerMoore_8h_source.html":[17,0,0,7,0],
-"LPfold_8h.html":[17,0,0,52],
-"LPfold_8h.html#ae85bf55053e9fb295208be322e0fa07a":[17,0,0,52,5],
-"LPfold_8h_source.html":[17,0,0,52],
-"Lfold_8h.html":[17,0,0,50],
-"Lfold_8h_source.html":[17,0,0,50],
-"MEA_8h.html":[17,0,0,53],
-"MEA_8h_source.html":[17,0,0,53],
-"PKplex_8h_source.html":[17,0,0,69],
-"PS__dot_8h.html":[17,0,0,77],
-"PS__dot_8h_source.html":[17,0,0,77],
-"ProfileAln_8h_source.html":[17,0,0,75],
+"LPfold_8h.html":[17,0,0,53],
+"LPfold_8h.html#ae85bf55053e9fb295208be322e0fa07a":[17,0,0,53,5],
+"LPfold_8h_source.html":[17,0,0,53],
+"Lfold_8h.html":[17,0,0,51],
+"Lfold_8h_source.html":[17,0,0,51],
+"MEA_8h.html":[17,0,0,54],
+"MEA_8h_source.html":[17,0,0,54],
+"PKplex_8h_source.html":[17,0,0,70],
+"PS__dot_8h.html":[17,0,0,78],
+"PS__dot_8h_source.html":[17,0,0,78],
+"ProfileAln_8h_source.html":[17,0,0,76],
 "RNApuzzler_8h.html":[17,0,0,6,0,0],
 "RNApuzzler_8h_source.html":[17,0,0,6,0,0],
-"RNAstruct_8h.html":[17,0,0,80],
-"RNAstruct_8h_source.html":[17,0,0,80],
+"RNAstruct_8h.html":[17,0,0,81],
+"RNAstruct_8h_source.html":[17,0,0,81],
 "RNAturtle_8h.html":[17,0,0,6,0,1],
 "RNAturtle_8h_source.html":[17,0,0,6,0,1],
 "SHAPE_8h.html":[17,0,0,0,3],
@@ -123,17 +123,17 @@ var NAVTREEINDEX0 =
 "design.html":[4,12],
 "design.html#design_api":[4,12,1],
 "design.html#design_intro":[4,12,0],
-"dir_15cd9e9f9fed42400220699de37de81c.html":[17,0,0,6,0],
-"dir_1b72173c60d46e2c13825429ad9f87ab.html":[17,0,0,2],
-"dir_1ed026dd4a6b3990a24ff2e0510f1e28.html":[17,0,0,8],
-"dir_6d7a52b325451b7ac0a99d06d420abcb.html":[17,0,0,3],
-"dir_788695b667a2248eec3656daa7404354.html":[17,0,0,5],
-"dir_856cfc6b1dfc1d665aea22b9048c064e.html":[17,0,0,7],
-"dir_99e275c152145741e4b8bbe1e7e65f5d.html":[17,0,0,1],
-"dir_b65dce601f6c2aa1a9f53e1dbd97d018.html":[17,0,0],
-"dir_d24edb0250b189e2f0cf5729e296356a.html":[17,0,0,6],
-"dir_e0244ac7ebefc16cab8ba03c1831bb2c.html":[17,0,0,4],
-"dir_fca7cdd19784fbd943eb50b086bcba79.html":[17,0,0,0],
+"dir_1ca6f3a46323f79e1934000abf5d4efb.html":[17,0,0,6],
+"dir_1ddf03e95848b6488d60454f7a385ded.html":[17,0,0,8],
+"dir_3d74ce004720553e7871f65d12e07ff9.html":[17,0,0,3],
+"dir_45ac42044d8b814ecf694abd17d2de12.html":[17,0,0,2],
+"dir_511ee2b14d6879b7ada858ff02a7ab24.html":[17,0,0,6,0],
+"dir_54da8e06181df970e10d68c1aa7bbb33.html":[17,0,0,4],
+"dir_8a4ca9b4a73205797ab566a10a6011af.html":[17,0,0,1],
+"dir_8b3d6293463b6781f7bf8859fc72e182.html":[17,0,0,5],
+"dir_94a42affd43e91f8a4e9ff1a4c7599c5.html":[17,0,0],
+"dir_e78bc76dd94a8744fef38d57611bd23c.html":[17,0,0,0],
+"dir_ece6de16e10c3ab1bafd819fa99af76e.html":[17,0,0,7],
 "dist__vars_8h.html":[17,0,0,29],
 "dist__vars_8h.html#aa03194c513af6b860e7b33e370b82bdb":[17,0,0,29,3],
 "dist__vars_8h.html#ab65d8ff14c6937612212526a60f59b3c":[17,0,0,29,5],
@@ -160,7 +160,6 @@ var NAVTREEINDEX0 =
 "energy_evaluation.html#sec_loop_decomposition_api":[4,2,0,0],
 "energy_evaluation.html#sec_model_details":[4,2,2],
 "equilibrium__probs_8h.html":[17,0,0,35],
-"equilibrium__probs_8h.html#aa88e17336daede0e6db4da1f3252c031":[17,0,0,35,7],
 "equilibrium__probs_8h_source.html":[17,0,0,35],
 "eval_8h.html":[17,0,0,36],
 "eval_8h_source.html":[17,0,0,36],
@@ -249,5 +248,6 @@ var NAVTREEINDEX0 =
 "functions_s.html":[16,2,0,18],
 "functions_t.html":[16,2,0,19],
 "functions_u.html":[16,2,0,20],
-"functions_vars.html":[16,2,1]
+"functions_vars.html":[16,2,1],
+"functions_vars.html":[16,2,1,0]
 };
