@@ -1,17 +1,33 @@
 var NAVTREEINDEX11 =
 {
+"part__func_8h.html#a68ba6f3a48e08ca131ab54621ce3a2d7":[17,0,0,65,29],
+"part__func_8h.html#a7b6ab474cc80accc48010ccfcc59f96b":[17,0,0,65,30],
+"part__func_8h.html#ae89a63bd83e75a80b2ba36d20b31ce81":[17,0,0,65,26],
+"part__func_8h.html#ae9556ba7ded44fe2321b6f67c3fc02a3":[17,0,0,65,28],
+"part__func_8h_source.html":[17,0,0,65],
+"part__func__co_8h.html":[17,0,0,66],
+"part__func__co_8h.html#afb35675f133966dc9f8a8c2c9686e13a":[17,0,0,66,2],
+"part__func__co_8h_source.html":[17,0,0,66],
+"part__func__up_8h.html":[17,0,0,67],
+"part__func__up_8h_source.html":[17,0,0,67],
+"part__func__window_8h.html":[17,0,0,68],
+"part__func__window_8h_source.html":[17,0,0,68],
+"paths_8h.html":[17,0,0,3,3],
+"paths_8h_source.html":[17,0,0,3,3],
+"perturbation__fold_8h.html":[17,0,0,69],
+"perturbation__fold_8h_source.html":[17,0,0,69],
 "pf_algorithm.html":[4,6],
 "pf_algorithm.html#sec_pf_api":[4,6,1],
 "pf_algorithm.html#sec_pf_intro":[4,6,0],
-"plex_8h_source.html":[17,0,0,70],
-"plot__aln_8h.html":[17,0,0,71],
-"plot__aln_8h_source.html":[17,0,0,71],
-"plot__layouts_8h.html":[17,0,0,72],
-"plot__layouts_8h_source.html":[17,0,0,72],
-"plot__structure_8h.html":[17,0,0,73],
-"plot__structure_8h_source.html":[17,0,0,73],
-"plot__utils_8h.html":[17,0,0,74],
-"plot__utils_8h_source.html":[17,0,0,74],
+"plex_8h_source.html":[17,0,0,71],
+"plot__aln_8h.html":[17,0,0,72],
+"plot__aln_8h_source.html":[17,0,0,72],
+"plot__layouts_8h.html":[17,0,0,73],
+"plot__layouts_8h_source.html":[17,0,0,73],
+"plot__structure_8h.html":[17,0,0,74],
+"plot__structure_8h_source.html":[17,0,0,74],
+"plot__utils_8h.html":[17,0,0,75],
+"plot__utils_8h_source.html":[17,0,0,75],
 "plots.html":[5,2],
 "plots.html#utils_aln":[5,2,2],
 "plots.html#utils_dot":[5,2,1],
@@ -26,17 +42,17 @@ var NAVTREEINDEX11 =
 "plotting_2utils_8h_source.html":[17,0,0,6,6],
 "probabilities_8h.html":[17,0,0,6,4],
 "probabilities_8h_source.html":[17,0,0,6,4],
-"profiledist_8h.html":[17,0,0,76],
-"profiledist_8h.html#a3dff26e707a2a2e65a0f759caabde6e7":[17,0,0,76,1],
-"profiledist_8h.html#a8e0b4fe3698b3502945116ecc0ba6160":[17,0,0,76,2],
-"profiledist_8h.html#a904c7eaf4a2413567c00ac4891749d18":[17,0,0,76,4],
-"profiledist_8h.html#a9b0b84a5a45761bf42d7c835dcdb3b85":[17,0,0,76,3],
-"profiledist_8h.html#abe75e90e00a1e5dd8862944ed53dad5d":[17,0,0,76,0],
-"profiledist_8h_source.html":[17,0,0,76],
-"read__epars_8h.html":[17,0,0,78],
-"read__epars_8h_source.html":[17,0,0,78],
-"ribo_8h.html":[17,0,0,79],
-"ribo_8h_source.html":[17,0,0,79],
+"profiledist_8h.html":[17,0,0,77],
+"profiledist_8h.html#a3dff26e707a2a2e65a0f759caabde6e7":[17,0,0,77,1],
+"profiledist_8h.html#a8e0b4fe3698b3502945116ecc0ba6160":[17,0,0,77,2],
+"profiledist_8h.html#a904c7eaf4a2413567c00ac4891749d18":[17,0,0,77,4],
+"profiledist_8h.html#a9b0b84a5a45761bf42d7c835dcdb3b85":[17,0,0,77,3],
+"profiledist_8h.html#abe75e90e00a1e5dd8862944ed53dad5d":[17,0,0,77,0],
+"profiledist_8h_source.html":[17,0,0,77],
+"read__epars_8h.html":[17,0,0,79],
+"read__epars_8h_source.html":[17,0,0,79],
+"ribo_8h.html":[17,0,0,80],
+"ribo_8h_source.html":[17,0,0,80],
 "rip.html":[4,8],
 "rip.html#rip_api":[4,8,3],
 "rip.html#rip_concat":[4,8,1],
@@ -61,25 +77,25 @@ var NAVTREEINDEX11 =
 "secondary_structures.html#pseudo-knots":[4,0,1,4],
 "secondary_structures.html#structure_abstraction":[4,0,1],
 "secondary_structures.html#structures":[4,0,0],
-"sequence_8h.html":[17,0,0,81],
-"sequence_8h_source.html":[17,0,0,81],
+"sequence_8h.html":[17,0,0,82],
+"sequence_8h_source.html":[17,0,0,82],
 "sequence_structure_data.html":[6,0],
-"snofold_8h_source.html":[17,0,0,82],
-"snoop_8h_source.html":[17,0,0,83],
+"snofold_8h_source.html":[17,0,0,83],
+"snoop_8h_source.html":[17,0,0,84],
 "soft_8h.html":[17,0,0,0,4],
 "soft_8h.html#ab926b4d8c342aa5fb2f8f007200635a8":[17,0,0,0,4,5],
 "soft_8h.html#ab926b4d8c342aa5fb2f8f007200635a8a0bd84aa58715eb7fb12cd385c7d27201":[17,0,0,0,4,5,0],
 "soft_8h.html#ab926b4d8c342aa5fb2f8f007200635a8a4a982ee6f7310949a504cc9f75f34581":[17,0,0,0,4,5,1],
 "soft_8h_source.html":[17,0,0,0,4],
-"special__const_8h_source.html":[17,0,0,84],
-"stream__output_8h.html":[17,0,0,85],
-"stream__output_8h_source.html":[17,0,0,85],
-"string__utils_8h.html":[17,0,0,86],
-"string__utils_8h_source.html":[17,0,0,86],
-"stringdist_8h.html":[17,0,0,87],
-"stringdist_8h.html#a3125991b3a403b3f89230474deb3f22e":[17,0,0,87,0],
-"stringdist_8h.html#a89e3c335ef17780576d7c0e713830db9":[17,0,0,87,1],
-"stringdist_8h_source.html":[17,0,0,87],
+"special__const_8h_source.html":[17,0,0,85],
+"stream__output_8h.html":[17,0,0,86],
+"stream__output_8h_source.html":[17,0,0,86],
+"string__utils_8h.html":[17,0,0,87],
+"string__utils_8h_source.html":[17,0,0,87],
+"stringdist_8h.html":[17,0,0,88],
+"stringdist_8h.html#a3125991b3a403b3f89230474deb3f22e":[17,0,0,88,0],
+"stringdist_8h.html#a89e3c335ef17780576d7c0e713830db9":[17,0,0,88,1],
+"stringdist_8h_source.html":[17,0,0,88],
 "strings_8h.html":[17,0,0,8,4],
 "strings_8h.html#a17b796b806f96b70382077fb5bc519bb":[17,0,0,8,4,17],
 "strings_8h.html#a1b95eac365a021572e1c37e5993a89be":[17,0,0,8,4,19],
@@ -106,8 +122,8 @@ var NAVTREEINDEX11 =
 "structTwoDpfold__vars.html#affb913470783f9edb12a0bfc22466269":[16,0,16,11],
 "struct__struct__en.html":[16,0,0],
 "structswString.html":[16,0,13],
-"structure__utils_8h.html":[17,0,0,88],
-"structure__utils_8h_source.html":[17,0,0,88],
+"structure__utils_8h.html":[17,0,0,89],
+"structure__utils_8h_source.html":[17,0,0,89],
 "structure_motifs.html":[4,15],
 "structure_motifs.html#structure_motif_api":[4,15,2],
 "structure_motifs.html#structure_motif_gquad":[4,15,1],
@@ -116,44 +132,44 @@ var NAVTREEINDEX11 =
 "structure_probing_data.html#structure_probing_SHAPE":[4,13,0,0],
 "structure_probing_data.html#structure_probing_api":[4,13,1],
 "structure_probing_data.html#structure_probing_intro":[4,13,0],
-"structured__domains_8h.html":[17,0,0,89],
-"structured__domains_8h_source.html":[17,0,0,89],
+"structured__domains_8h.html":[17,0,0,90],
+"structured__domains_8h_source.html":[17,0,0,90],
 "structvrna__dimer__conc__s.html":[16,0,23],
 "structvrna__dimer__conc__s.html#a5763381efee22a0bbec2f2d0754f7697":[16,0,23,1],
 "structvrna__dimer__conc__s.html#a6e64ce1afbc93756afef06c0e3ccce97":[16,0,23,0],
 "structvrna__dimer__conc__s.html#aef56a1fe8d7f07e7b5d9a65417dda8a4":[16,0,23,2],
-"structvrna__sc__bp__storage__t.html":[16,0,43],
-"structvrna__sc__motif__s.html":[16,0,44],
-"structvrna__structured__domains__s.html":[16,0,50],
-"structvrna__subopt__sol__s.html":[16,0,51],
-"structvrna__subopt__sol__s.html#a3c632c7f08eb6a8827c6151625e5ef8e":[16,0,51,1],
-"structvrna__subopt__sol__s.html#a99bc26ca68392aa4656386cf73b73fef":[16,0,51,0],
-"structvrna__unstructured__domain__motif__s.html":[16,0,52],
-"subopt_8h.html":[17,0,0,90],
-"subopt_8h.html#a01ae9a0f27d245d89f705afd843fc457":[17,0,0,90,2],
-"subopt_8h.html#a5ec740b80afb4906ba4311dbd8ddbd89":[17,0,0,90,1],
-"subopt_8h.html#aa0f46ff02e1017469cf902d02ecd7f9a":[17,0,0,90,4],
-"subopt_8h_source.html":[17,0,0,90],
+"structvrna__sc__bp__storage__t.html":[16,0,44],
+"structvrna__sc__motif__s.html":[16,0,45],
+"structvrna__structured__domains__s.html":[16,0,51],
+"structvrna__subopt__sol__s.html":[16,0,52],
+"structvrna__subopt__sol__s.html#a3c632c7f08eb6a8827c6151625e5ef8e":[16,0,52,1],
+"structvrna__subopt__sol__s.html#a99bc26ca68392aa4656386cf73b73fef":[16,0,52,0],
+"structvrna__unstructured__domain__motif__s.html":[16,0,53],
+"subopt_8h.html":[17,0,0,91],
+"subopt_8h.html#a01ae9a0f27d245d89f705afd843fc457":[17,0,0,91,2],
+"subopt_8h.html#a5ec740b80afb4906ba4311dbd8ddbd89":[17,0,0,91,1],
+"subopt_8h.html#aa0f46ff02e1017469cf902d02ecd7f9a":[17,0,0,91,4],
+"subopt_8h_source.html":[17,0,0,91],
 "suboptimal_structures.html":[4,7],
 "suboptimal_structures.html#sec_samples":[4,7,1],
 "suboptimal_structures.html#sec_suboptimals":[4,7,0],
 "suboptimal_structures.html#sec_suboptimals_api":[4,7,2],
 "svm_8h_source.html":[17,0,0,8,6],
-"svm__utils_8h.html":[17,0,0,91],
-"svm__utils_8h_source.html":[17,0,0,91],
-"treedist_8h.html":[17,0,0,92],
-"treedist_8h.html#a08fe4d5afd385dce593b86eaf010c6e3":[17,0,0,92,0],
-"treedist_8h.html#a21ad4de3ba4055aeef08b28c9ad48894":[17,0,0,92,2],
-"treedist_8h.html#a3b21f1925f7071f46d93431a835217bb":[17,0,0,92,1],
-"treedist_8h.html#acbc1cb9bce582ea945e4a467c76a57aa":[17,0,0,92,3],
-"treedist_8h_source.html":[17,0,0,92],
-"ugly__bt_8h_source.html":[17,0,0,93],
-"units_8h.html":[17,0,0,94],
-"units_8h_source.html":[17,0,0,94],
-"unstructured__domains_8h.html":[17,0,0,95],
-"unstructured__domains_8h.html#a13ac877c9db89a1a5b5d9c0394148595":[17,0,0,95,23],
-"unstructured__domains_8h.html#aea51485feeafed1f93222ba7db9fc3b1":[17,0,0,95,18],
-"unstructured__domains_8h_source.html":[17,0,0,95],
+"svm__utils_8h.html":[17,0,0,92],
+"svm__utils_8h_source.html":[17,0,0,92],
+"treedist_8h.html":[17,0,0,93],
+"treedist_8h.html#a08fe4d5afd385dce593b86eaf010c6e3":[17,0,0,93,0],
+"treedist_8h.html#a21ad4de3ba4055aeef08b28c9ad48894":[17,0,0,93,2],
+"treedist_8h.html#a3b21f1925f7071f46d93431a835217bb":[17,0,0,93,1],
+"treedist_8h.html#acbc1cb9bce582ea945e4a467c76a57aa":[17,0,0,93,3],
+"treedist_8h_source.html":[17,0,0,93],
+"ugly__bt_8h_source.html":[17,0,0,94],
+"units_8h.html":[17,0,0,95],
+"units_8h_source.html":[17,0,0,95],
+"unstructured__domains_8h.html":[17,0,0,96],
+"unstructured__domains_8h.html#a13ac877c9db89a1a5b5d9c0394148595":[17,0,0,96,23],
+"unstructured__domains_8h.html#aea51485feeafed1f93222ba7db9fc3b1":[17,0,0,96,18],
+"unstructured__domains_8h_source.html":[17,0,0,96],
 "utilities.html":[8],
 "utils_2alignments_8h.html":[17,0,0,8,0],
 "utils_2alignments_8h_source.html":[17,0,0,8,0],
@@ -173,16 +189,19 @@ var NAVTREEINDEX11 =
 "utils_2basic_8h_source.html":[17,0,0,8,1],
 "utils_2structures_8h.html":[17,0,0,8,5],
 "utils_2structures_8h_source.html":[17,0,0,8,5],
-"utils_8h.html":[17,0,0,96],
-"utils_8h_source.html":[17,0,0,96],
-"vrna__config_8h_source.html":[17,0,0,97],
-"walk_8h.html":[17,0,0,98],
-"walk_8h_source.html":[17,0,0,98],
+"utils_2units_8h.html":[17,0,0,8,7],
+"utils_2units_8h_source.html":[17,0,0,8,7],
+"utils_8h.html":[17,0,0,97],
+"utils_8h_source.html":[17,0,0,97],
+"vrna__config_8h_source.html":[17,0,0,98],
+"walk_8h.html":[17,0,0,99],
+"walk_8h_source.html":[17,0,0,99],
 "wrappers.html":[7,2],
 "wrappers.html#scripting_examples":[7,2,3],
 "wrappers.html#scripting_globals":[7,2,1,0],
 "wrappers.html#scripting_intro":[7,2,0],
 "wrappers.html#scripting_oo_interface":[7,2,2],
 "wrappers.html#scripting_renaming":[7,2,1],
-"wrappers.html#scripting_wrapper_notes":[7,2,4]
+"wrappers.html#scripting_wrapper_notes":[7,2,4],
+"zscore_8h_source.html":[17,0,0,100]
 };
