@@ -1,58 +1,38 @@
 var NAVTREEINDEX8 =
 {
-"group__paths__walk.html#ga0b84bd36bfd783130297797c51dd85ae":[17,0,0,3,4,1],
-"group__paths__walk.html#ga0b84bd36bfd783130297797c51dd85ae":[15,2,1,1,1],
-"group__paths__walk.html#ga1ee63e54ecf136491e12ff03ede2622d":[15,2,1,1,2],
-"group__paths__walk.html#ga1ee63e54ecf136491e12ff03ede2622d":[17,0,0,3,4,2],
-"group__paths__walk.html#ga705cea2b3243a38a2d6e3b1e141ed061":[17,0,0,3,4,0],
-"group__paths__walk.html#ga705cea2b3243a38a2d6e3b1e141ed061":[15,2,1,1,0],
-"group__paths__walk.html#ga9594d7424dbe301f0dd3f4900db0f05c":[15,2,1,1,5],
-"group__paths__walk.html#ga9594d7424dbe301f0dd3f4900db0f05c":[17,0,0,3,4,5],
-"group__paths__walk.html#ga98fdc3f5cfa36a12738c2ec1ce024570":[15,2,1,1,6],
-"group__paths__walk.html#ga98fdc3f5cfa36a12738c2ec1ce024570":[17,0,0,3,4,6],
-"group__paths__walk.html#gaef7afadc36933b80706de49fe36e7b94":[15,2,1,1,4],
-"group__paths__walk.html#gaef7afadc36933b80706de49fe36e7b94":[17,0,0,3,4,4],
-"group__paths__walk.html#gaf1bb1f8fec8d24e3b821f621b19f77b4":[17,0,0,3,4,3],
-"group__paths__walk.html#gaf1bb1f8fec8d24e3b821f621b19f77b4":[15,2,1,1,3],
-"group__perturbation.html":[15,9,1],
-"group__perturbation.html#ga5aaeafe1b0aa77a5cda18943ff94b02f":[17,0,0,68,4],
-"group__perturbation.html#ga5aaeafe1b0aa77a5cda18943ff94b02f":[15,9,1,5],
-"group__perturbation.html#ga7b0a65c6c92fa1d8012383ba9d3dcb4f":[15,9,1,7],
-"group__perturbation.html#ga7b0a65c6c92fa1d8012383ba9d3dcb4f":[17,0,0,68,6],
-"group__perturbation.html#ga81e10993d1ae728e4e02022b33155a12":[17,0,0,68,0],
 "group__perturbation.html#ga81e10993d1ae728e4e02022b33155a12":[15,9,1,1],
-"group__perturbation.html#ga9be8a702cddf58235571ace11cc41b22":[17,0,0,68,5],
+"group__perturbation.html#ga9be8a702cddf58235571ace11cc41b22":[17,0,0,69,5],
 "group__perturbation.html#ga9be8a702cddf58235571ace11cc41b22":[15,9,1,6],
-"group__perturbation.html#ga9ecd2144c2ebed7533233da3986521b0":[17,0,0,68,7],
+"group__perturbation.html#ga9ecd2144c2ebed7533233da3986521b0":[17,0,0,69,7],
 "group__perturbation.html#ga9ecd2144c2ebed7533233da3986521b0":[15,9,1,8],
+"group__perturbation.html#gaa124bdc20d88001c38ade590c4bcc3c4":[17,0,0,69,9],
 "group__perturbation.html#gaa124bdc20d88001c38ade590c4bcc3c4":[15,9,1,10],
-"group__perturbation.html#gaa124bdc20d88001c38ade590c4bcc3c4":[17,0,0,68,9],
-"group__perturbation.html#gaa715397c7afd2d2955c315512a3d571a":[17,0,0,68,8],
+"group__perturbation.html#gaa715397c7afd2d2955c315512a3d571a":[17,0,0,69,8],
 "group__perturbation.html#gaa715397c7afd2d2955c315512a3d571a":[15,9,1,9],
-"group__perturbation.html#gab1d89db58e8c497795a5005f5dbc8c4a":[17,0,0,68,3],
+"group__perturbation.html#gab1d89db58e8c497795a5005f5dbc8c4a":[17,0,0,69,3],
 "group__perturbation.html#gab1d89db58e8c497795a5005f5dbc8c4a":[15,9,1,4],
+"group__perturbation.html#gac070dfb9cafaeb14d5652bd9adf0f6b1":[17,0,0,69,1],
 "group__perturbation.html#gac070dfb9cafaeb14d5652bd9adf0f6b1":[15,9,1,2],
-"group__perturbation.html#gac070dfb9cafaeb14d5652bd9adf0f6b1":[17,0,0,68,1],
-"group__perturbation.html#gae5126200d80dbb282f46083fffc606bf":[17,0,0,68,2],
+"group__perturbation.html#gae5126200d80dbb282f46083fffc606bf":[17,0,0,69,2],
 "group__perturbation.html#gae5126200d80dbb282f46083fffc606bf":[15,9,1,3],
 "group__pf__cofold.html":[15,6,0],
-"group__pf__cofold.html#ga444df1587c9a2ca15b8eb25188f629c3":[17,0,0,64,0],
+"group__pf__cofold.html#ga444df1587c9a2ca15b8eb25188f629c3":[17,0,0,65,0],
 "group__pf__cofold.html#ga444df1587c9a2ca15b8eb25188f629c3":[15,6,0,3],
 "group__pf__cofold.html#ga46244c7adf5040580291c45b465f4efa":[17,0,0,21,2],
 "group__pf__cofold.html#ga46244c7adf5040580291c45b465f4efa":[15,6,0,5],
-"group__pf__cofold.html#ga5445d8d96a40e9e79b1fa5a7f1a6b7ea":[17,0,0,64,1],
+"group__pf__cofold.html#ga5445d8d96a40e9e79b1fa5a7f1a6b7ea":[17,0,0,65,1],
 "group__pf__cofold.html#ga5445d8d96a40e9e79b1fa5a7f1a6b7ea":[15,6,0,4],
 "group__pf__cofold.html#ga83b8d5d0f7875d6d5013b208f23e3356":[17,0,0,21,3],
 "group__pf__cofold.html#ga83b8d5d0f7875d6d5013b208f23e3356":[15,6,0,7],
+"group__pf__cofold.html#gac2d1851a710a8561390861155ca988fe":[17,0,0,66,10],
 "group__pf__cofold.html#gac2d1851a710a8561390861155ca988fe":[15,6,0,9],
-"group__pf__cofold.html#gac2d1851a710a8561390861155ca988fe":[17,0,0,65,10],
 "group__pf__cofold.html#gac48c2723444ecfdceafcfd525ca98322":[17,0,0,21,1],
 "group__pf__cofold.html#gac48c2723444ecfdceafcfd525ca98322":[15,6,0,2],
-"group__pf__cofold.html#gaff27888c4088cc1f60fd59cbd589474c":[17,0,0,65,9],
+"group__pf__cofold.html#gaff27888c4088cc1f60fd59cbd589474c":[17,0,0,66,9],
 "group__pf__cofold.html#gaff27888c4088cc1f60fd59cbd589474c":[15,6,0,8],
 "group__pf__fold.html":[15,4],
-"group__pf__fold.html#gad2b3594f0b50b68029e0f54fdce59313":[17,0,0,64,9],
-"group__pf__fold.html#gad2b3594f0b50b68029e0f54fdce59313":[15,4,6],
+"group__pf__fold.html#gad2b3594f0b50b68029e0f54fdce59313":[17,0,0,65,9],
+"group__pf__fold.html#gad2b3594f0b50b68029e0f54fdce59313":[15,4,5],
 "group__plot__layout__utils.html":[15,12,5,0],
 "group__plot__layout__utils.html#ga195139110e2877b92c7f82d05b6dad19":[15,12,5,0,27],
 "group__plot__layout__utils.html#ga195139110e2877b92c7f82d05b6dad19":[17,0,0,6,0,1,0],
@@ -60,8 +40,8 @@ var NAVTREEINDEX8 =
 "group__plot__layout__utils.html#ga2e2adbef0283a8ff2dfe5284eb1f4a6a":[17,0,0,6,2,13],
 "group__plot__layout__utils.html#ga382c1c5c0b1943500aa4bb55b7658a33":[15,12,5,0,5],
 "group__plot__layout__utils.html#ga382c1c5c0b1943500aa4bb55b7658a33":[17,0,0,6,2,3],
-"group__plot__layout__utils.html#ga3d3531ebbca9054240c73bff115c4dcf":[15,12,5,0,28],
 "group__plot__layout__utils.html#ga3d3531ebbca9054240c73bff115c4dcf":[17,0,0,6,0,1,1],
+"group__plot__layout__utils.html#ga3d3531ebbca9054240c73bff115c4dcf":[15,12,5,0,28],
 "group__plot__layout__utils.html#ga41d94adbd42e1a570d840756e6dd6909":[15,12,5,0,11],
 "group__plot__layout__utils.html#ga41d94adbd42e1a570d840756e6dd6909":[17,0,0,6,2,9],
 "group__plot__layout__utils.html#ga47ff1fd92e9658361a758fdb03122911":[15,12,5,0,19],
@@ -70,24 +50,24 @@ var NAVTREEINDEX8 =
 "group__plot__layout__utils.html#ga4ecd3401e22933a44bf31d14320e59b1":[17,0,0,6,2,10],
 "group__plot__layout__utils.html#ga551344268c4245f3f75994a51c517a30":[15,12,5,0,26],
 "group__plot__layout__utils.html#ga551344268c4245f3f75994a51c517a30":[17,0,0,6,0,0,3],
-"group__plot__layout__utils.html#ga57f815d56c8c083c016381213f581f1e":[15,12,5,0,13],
 "group__plot__layout__utils.html#ga57f815d56c8c083c016381213f581f1e":[17,0,0,6,2,11],
+"group__plot__layout__utils.html#ga57f815d56c8c083c016381213f581f1e":[15,12,5,0,13],
 "group__plot__layout__utils.html#ga64ec68055e241d11f659edb50f27ecae":[15,12,5,0,6],
 "group__plot__layout__utils.html#ga64ec68055e241d11f659edb50f27ecae":[17,0,0,6,2,4],
-"group__plot__layout__utils.html#ga76788091848e73cfb24b31536e22b7dd":[17,0,0,6,2,16],
 "group__plot__layout__utils.html#ga76788091848e73cfb24b31536e22b7dd":[15,12,5,0,18],
+"group__plot__layout__utils.html#ga76788091848e73cfb24b31536e22b7dd":[17,0,0,6,2,16],
 "group__plot__layout__utils.html#ga7953b759eada86c61b0a4aebe0dc67d1":[15,12,5,0,8],
 "group__plot__layout__utils.html#ga7953b759eada86c61b0a4aebe0dc67d1":[17,0,0,6,2,6],
-"group__plot__layout__utils.html#ga838ff131d5430461d0c4c41c4aba45bc":[15,12,5,0,25],
 "group__plot__layout__utils.html#ga838ff131d5430461d0c4c41c4aba45bc":[17,0,0,6,0,0,2],
+"group__plot__layout__utils.html#ga838ff131d5430461d0c4c41c4aba45bc":[15,12,5,0,25],
 "group__plot__layout__utils.html#ga8b09019a429c7c2447be94901c7ed658":[17,0,0,6,2,7],
 "group__plot__layout__utils.html#ga8b09019a429c7c2447be94901c7ed658":[15,12,5,0,9],
 "group__plot__layout__utils.html#ga8c9eac631348da92136c8363ecdd9fb9":[15,12,5,0,4],
 "group__plot__layout__utils.html#ga8c9eac631348da92136c8363ecdd9fb9":[17,0,0,6,2,2],
 "group__plot__layout__utils.html#ga94d4c863ecac2f220f76658afb92f964":[15,12,5,0,3],
 "group__plot__layout__utils.html#ga94d4c863ecac2f220f76658afb92f964":[17,0,0,6,2,1],
-"group__plot__layout__utils.html#ga996128730020a2d7a7368b4248195931":[15,12,5,0,14],
 "group__plot__layout__utils.html#ga996128730020a2d7a7368b4248195931":[17,0,0,6,2,12],
+"group__plot__layout__utils.html#ga996128730020a2d7a7368b4248195931":[15,12,5,0,14],
 "group__plot__layout__utils.html#gaa5089debe89c11e301dea04b3236efe3":[15,12,5,0,22],
 "group__plot__layout__utils.html#gaa5089debe89c11e301dea04b3236efe3":[17,0,0,6,3,1],
 "group__plot__layout__utils.html#gab0e886afe200db9323e4e65d44738177":[17,0,0,6,2,8],
@@ -96,18 +76,18 @@ var NAVTREEINDEX8 =
 "group__plot__layout__utils.html#gab50a90dd6000a1920d741537af7e0b24":[17,0,0,6,0,0,1],
 "group__plot__layout__utils.html#gac0335e398d01202c77c1d7b28811b761":[15,12,5,0,21],
 "group__plot__layout__utils.html#gac0335e398d01202c77c1d7b28811b761":[17,0,0,6,3,0],
-"group__plot__layout__utils.html#gac986fe092abc2a6a93ceb5141e4dd28b":[15,12,5,0,7],
 "group__plot__layout__utils.html#gac986fe092abc2a6a93ceb5141e4dd28b":[17,0,0,6,2,5],
-"group__plot__layout__utils.html#gaccd6a87cb324b7d680e5dd93e112738b":[17,0,0,6,2,14],
+"group__plot__layout__utils.html#gac986fe092abc2a6a93ceb5141e4dd28b":[15,12,5,0,7],
 "group__plot__layout__utils.html#gaccd6a87cb324b7d680e5dd93e112738b":[15,12,5,0,16],
+"group__plot__layout__utils.html#gaccd6a87cb324b7d680e5dd93e112738b":[17,0,0,6,2,14],
 "group__plot__layout__utils.html#gae6d17b9f0a53cf5205a9181e0f8422e9":[17,0,0,6,2,0],
 "group__plot__layout__utils.html#gae6d17b9f0a53cf5205a9181e0f8422e9":[15,12,5,0,2],
 "group__plot__layout__utils.html#gaea0dada4d0113d16d4890bc0937292e6":[15,12,5,0,17],
 "group__plot__layout__utils.html#gaea0dada4d0113d16d4890bc0937292e6":[17,0,0,6,2,15],
-"group__plot__layout__utils.html#gaeec80faa235f3ca489bc5e50adc41460":[17,0,0,6,2,18],
 "group__plot__layout__utils.html#gaeec80faa235f3ca489bc5e50adc41460":[15,12,5,0,20],
-"group__plot__layout__utils.html#gafd49896df8780c9669125429bc0da9b3":[17,0,0,6,0,0,0],
+"group__plot__layout__utils.html#gaeec80faa235f3ca489bc5e50adc41460":[17,0,0,6,2,18],
 "group__plot__layout__utils.html#gafd49896df8780c9669125429bc0da9b3":[15,12,5,0,23],
+"group__plot__layout__utils.html#gafd49896df8780c9669125429bc0da9b3":[17,0,0,6,0,0,0],
 "group__plot__layout__utils.html#structvrna__plot__layout__s":[15,12,5,0,0],
 "group__plot__layout__utils.html#structvrna__plot__options__puzzler__t":[15,12,5,0,1],
 "group__plotting__utils.html":[15,12,5],
@@ -127,10 +107,10 @@ var NAVTREEINDEX8 =
 "group__plotting__utils.html#ga689a97a7e3b8a2df14728b8204d9d57b":[17,0,0,6,4,1],
 "group__plotting__utils.html#ga70834bc8c0aad4fe6824ff76ccb8f329":[15,12,5,17],
 "group__plotting__utils.html#ga70834bc8c0aad4fe6824ff76ccb8f329":[17,0,0,6,5,2],
-"group__plotting__utils.html#gabdc8f6548ba4a3bc3cd868ccbcfdb86a":[17,0,0,6,5,0],
 "group__plotting__utils.html#gabdc8f6548ba4a3bc3cd868ccbcfdb86a":[15,12,5,15],
-"group__plotting__utils.html#gadd368528755f9a830727b680243541df":[17,0,0,6,5,3],
+"group__plotting__utils.html#gabdc8f6548ba4a3bc3cd868ccbcfdb86a":[17,0,0,6,5,0],
 "group__plotting__utils.html#gadd368528755f9a830727b680243541df":[15,12,5,18],
+"group__plotting__utils.html#gadd368528755f9a830727b680243541df":[17,0,0,6,5,3],
 "group__plotting__utils.html#gae7853539b5df98f294b4af434e979304":[15,12,5,19],
 "group__plotting__utils.html#gae7853539b5df98f294b4af434e979304":[17,0,0,6,5,4],
 "group__plotting__utils.html#structvrna__dotplot__auxdata__t":[15,12,5,12],
@@ -141,17 +121,17 @@ var NAVTREEINDEX8 =
 "group__plotting__utils__deprecated.html#ga821802c3685e37e15182341f6217470d":[17,0,0,6,1,2],
 "group__plotting__utils__deprecated.html#ga948111b910926f0405a3fa920c790816":[15,12,5,3,5],
 "group__plotting__utils__deprecated.html#ga948111b910926f0405a3fa920c790816":[17,0,0,6,3,2],
-"group__plotting__utils__deprecated.html#gaab48d4dac655d688abe921389ac2847c":[17,0,0,6,1,3],
 "group__plotting__utils__deprecated.html#gaab48d4dac655d688abe921389ac2847c":[15,12,5,3,2],
+"group__plotting__utils__deprecated.html#gaab48d4dac655d688abe921389ac2847c":[17,0,0,6,1,3],
 "group__plotting__utils__deprecated.html#gac4ea13d35308f09940178d2b05a248c2":[15,12,5,3,4],
 "group__plotting__utils__deprecated.html#gac4ea13d35308f09940178d2b05a248c2":[17,0,0,6,2,20],
-"group__plotting__utils__deprecated.html#gaf4b9173e7d3fd361c3c85e6def194123":[15,12,5,3,3],
 "group__plotting__utils__deprecated.html#gaf4b9173e7d3fd361c3c85e6def194123":[17,0,0,6,2,19],
+"group__plotting__utils__deprecated.html#gaf4b9173e7d3fd361c3c85e6def194123":[15,12,5,3,3],
 "group__plotting__utils__deprecated.html#structCOORDINATE":[15,12,5,3,0],
 "group__probing__data.html":[15,9],
 "group__search__utils.html":[15,12,6],
-"group__search__utils.html#ga1d675ef5dcdcc8c33a1b79956a246697":[15,12,6,4],
 "group__search__utils.html#ga1d675ef5dcdcc8c33a1b79956a246697":[17,0,0,7,0,3],
+"group__search__utils.html#ga1d675ef5dcdcc8c33a1b79956a246697":[15,12,6,4],
 "group__search__utils.html#ga72574a7cf9786d825ce73f7f7748d3c4":[15,12,6,2],
 "group__search__utils.html#ga72574a7cf9786d825ce73f7f7748d3c4":[17,0,0,7,0,1],
 "group__search__utils.html#ga8af89ab58905851f3dbd52624227d372":[15,12,6,1],
@@ -175,8 +155,8 @@ var NAVTREEINDEX8 =
 "group__soft__constraints.html#ad939d2511afe7b3db9b802fdeff2bac4":[15,1,3,1,1,6],
 "group__soft__constraints.html#ga069915fe203a2c8e522dd37847177a09":[15,1,3,1,10],
 "group__soft__constraints.html#ga069915fe203a2c8e522dd37847177a09":[17,0,0,0,4,10],
-"group__soft__constraints.html#ga15c6d52471ec97897e2bb7f964f5deb6":[17,0,0,0,4,13],
 "group__soft__constraints.html#ga15c6d52471ec97897e2bb7f964f5deb6":[15,1,3,1,13],
+"group__soft__constraints.html#ga15c6d52471ec97897e2bb7f964f5deb6":[17,0,0,0,4,13],
 "group__soft__constraints.html#ga4099978d410513edeeff8f3db13144c5":[15,1,3,1,4],
 "group__soft__constraints.html#ga4099978d410513edeeff8f3db13144c5":[17,0,0,0,4,3],
 "group__soft__constraints.html#ga6d55446448d69346fc313b993c4fb3e8":[15,1,3,1,12],
@@ -191,8 +171,8 @@ var NAVTREEINDEX8 =
 "group__soft__constraints.html#ga88a266695d9e25cc12114dceb7b4565e":[17,0,0,0,4,2],
 "group__soft__constraints.html#ga8c7d907ec0125cd61c04e0908010a4e9":[15,1,3,1,14],
 "group__soft__constraints.html#ga8c7d907ec0125cd61c04e0908010a4e9":[17,0,0,0,4,14],
-"group__soft__constraints.html#ga8e4334b24bc91453fbcda490a4e331af":[17,0,0,0,4,7],
 "group__soft__constraints.html#ga8e4334b24bc91453fbcda490a4e331af":[15,1,3,1,7],
+"group__soft__constraints.html#ga8e4334b24bc91453fbcda490a4e331af":[17,0,0,0,4,7],
 "group__soft__constraints.html#ga99ed63f3ef9e7fe3997932030487a344":[15,1,3,1,9],
 "group__soft__constraints.html#ga99ed63f3ef9e7fe3997932030487a344":[17,0,0,0,4,9],
 "group__soft__constraints.html#ga9d977a1681356778cc66dceafbe5b032":[15,1,3,1,6],
@@ -207,8 +187,6 @@ var NAVTREEINDEX8 =
 "group__string__utils.html":[15,12,1],
 "group__string__utils.html#ga03943706e48069237cd57f2d35ca987e":[17,0,0,8,4,0],
 "group__string__utils.html#ga03943706e48069237cd57f2d35ca987e":[15,12,1,1],
-"group__string__utils.html#ga0d031df5266328fe455e244e094634fd":[17,0,0,8,4,14],
-"group__string__utils.html#ga0d031df5266328fe455e244e094634fd":[15,12,1,15],
 "group__string__utils.html#ga122df216996ba62fd5056b7743e3131a":[17,0,0,8,4,7],
 "group__string__utils.html#ga122df216996ba62fd5056b7743e3131a":[15,12,1,8],
 "group__string__utils.html#ga1fbd821d4408cc5f1dd9d12c15e092cb":[17,0,0,8,4,16],
@@ -217,37 +195,59 @@ var NAVTREEINDEX8 =
 "group__string__utils.html#ga301798b43b6f66687985c725efd14f32":[15,12,1,11],
 "group__string__utils.html#ga33c3b1826b8e2739f09f111ec719ded5":[17,0,0,8,4,3],
 "group__string__utils.html#ga33c3b1826b8e2739f09f111ec719ded5":[15,12,1,4],
-"group__string__utils.html#ga33cc0190a326ec368277caa777b8bf18":[17,0,0,8,4,4],
 "group__string__utils.html#ga33cc0190a326ec368277caa777b8bf18":[15,12,1,5],
-"group__string__utils.html#ga459fdee190ed81bb7773cbaf671748a9":[15,12,1,6],
+"group__string__utils.html#ga33cc0190a326ec368277caa777b8bf18":[17,0,0,8,4,4],
 "group__string__utils.html#ga459fdee190ed81bb7773cbaf671748a9":[17,0,0,8,4,5],
-"group__string__utils.html#ga4eeb3750dcf860b9f3158249f95dbd7f":[17,0,0,8,4,9],
+"group__string__utils.html#ga459fdee190ed81bb7773cbaf671748a9":[15,12,1,6],
 "group__string__utils.html#ga4eeb3750dcf860b9f3158249f95dbd7f":[15,12,1,10],
+"group__string__utils.html#ga4eeb3750dcf860b9f3158249f95dbd7f":[17,0,0,8,4,9],
 "group__string__utils.html#ga4f44dca03c9d708d68e64c0610bb9091":[17,0,0,8,4,13],
 "group__string__utils.html#ga4f44dca03c9d708d68e64c0610bb9091":[15,12,1,14],
-"group__string__utils.html#ga5d1c2271e79d9bcb52d4e68360763fb9":[15,12,1,12],
 "group__string__utils.html#ga5d1c2271e79d9bcb52d4e68360763fb9":[17,0,0,8,4,11],
+"group__string__utils.html#ga5d1c2271e79d9bcb52d4e68360763fb9":[15,12,1,12],
 "group__string__utils.html#ga6388870e639eee9c0a69446876f1f8cc":[17,0,0,8,4,1],
 "group__string__utils.html#ga6388870e639eee9c0a69446876f1f8cc":[15,12,1,2],
-"group__string__utils.html#ga74f05ece32ea73b59f84a7452afd5fae":[15,12,1,16],
 "group__string__utils.html#ga74f05ece32ea73b59f84a7452afd5fae":[17,0,0,8,4,15],
-"group__string__utils.html#gac0771ec71316023067f2aae61a5aa0fb":[17,0,0,8,4,6],
+"group__string__utils.html#ga74f05ece32ea73b59f84a7452afd5fae":[15,12,1,16],
+"group__string__utils.html#ga88abbd373840ec90ff5d876f72cf4f18":[17,0,0,8,4,14],
+"group__string__utils.html#ga88abbd373840ec90ff5d876f72cf4f18":[15,12,1,15],
 "group__string__utils.html#gac0771ec71316023067f2aae61a5aa0fb":[15,12,1,7],
-"group__string__utils.html#gac632775617f4b2df096bfe8efb53d07f":[15,12,1,9],
+"group__string__utils.html#gac0771ec71316023067f2aae61a5aa0fb":[17,0,0,8,4,6],
 "group__string__utils.html#gac632775617f4b2df096bfe8efb53d07f":[17,0,0,8,4,8],
-"group__string__utils.html#gacfed92cba77064f6c743f9118d079bfc":[17,0,0,8,4,12],
+"group__string__utils.html#gac632775617f4b2df096bfe8efb53d07f":[15,12,1,9],
 "group__string__utils.html#gacfed92cba77064f6c743f9118d079bfc":[15,12,1,13],
-"group__string__utils.html#gafb228174279df9486a5cb56ac0bc79a3":[17,0,0,8,4,2],
+"group__string__utils.html#gacfed92cba77064f6c743f9118d079bfc":[17,0,0,8,4,12],
 "group__string__utils.html#gafb228174279df9486a5cb56ac0bc79a3":[15,12,1,3],
+"group__string__utils.html#gafb228174279df9486a5cb56ac0bc79a3":[17,0,0,8,4,2],
 "group__struct__utils.html":[15,12,2],
-"group__struct__utils.html#ga025bff1b27fa46534c8fae6980f64bb5":[17,0,0,8,5,46],
 "group__struct__utils.html#ga025bff1b27fa46534c8fae6980f64bb5":[15,12,2,12],
-"group__struct__utils.html#ga03e15af299be0866ff21da880c74b92e":[17,0,0,8,5,41],
+"group__struct__utils.html#ga025bff1b27fa46534c8fae6980f64bb5":[17,0,0,8,5,46],
 "group__struct__utils.html#ga03e15af299be0866ff21da880c74b92e":[15,12,2,7],
-"group__struct__utils.html#ga0c28c410a5ab22d6ab9c77a84e8d5b44":[17,0,0,8,5,45],
+"group__struct__utils.html#ga03e15af299be0866ff21da880c74b92e":[17,0,0,8,5,41],
 "group__struct__utils.html#ga0c28c410a5ab22d6ab9c77a84e8d5b44":[15,12,2,11],
-"group__struct__utils.html#ga27bea2c241564af53a065982183389df":[15,12,2,13],
+"group__struct__utils.html#ga0c28c410a5ab22d6ab9c77a84e8d5b44":[17,0,0,8,5,45],
 "group__struct__utils.html#ga27bea2c241564af53a065982183389df":[17,0,0,8,5,47],
+"group__struct__utils.html#ga27bea2c241564af53a065982183389df":[15,12,2,13],
+"group__struct__utils.html#ga5a27bd058183170afd4716f5b8ff511a":[17,0,0,8,5,44],
 "group__struct__utils.html#ga5a27bd058183170afd4716f5b8ff511a":[15,12,2,10],
-"group__struct__utils.html#ga5a27bd058183170afd4716f5b8ff511a":[17,0,0,8,5,44]
+"group__struct__utils.html#ga65bdfbac6a16bf30286e8a3f7d15f60a":[17,0,0,8,5,42],
+"group__struct__utils.html#ga65bdfbac6a16bf30286e8a3f7d15f60a":[15,12,2,8],
+"group__struct__utils.html#gab4c2a00c99ce1d612ffa5bde114eb96d":[15,12,2,9],
+"group__struct__utils.html#gab4c2a00c99ce1d612ffa5bde114eb96d":[17,0,0,8,5,43],
+"group__struct__utils__deprecated.html":[15,12,2,5],
+"group__struct__utils__deprecated.html#ga0518a287aa4a870508cea819029778ab":[15,12,2,5,26],
+"group__struct__utils__deprecated.html#ga0518a287aa4a870508cea819029778ab":[17,0,0,81,12],
+"group__struct__utils__deprecated.html#ga071c6921efe1eb974f115ee6fefa3c39":[15,12,2,5,12],
+"group__struct__utils__deprecated.html#ga071c6921efe1eb974f115ee6fefa3c39":[17,0,0,8,5,53],
+"group__struct__utils__deprecated.html#ga07b7e90e712559a1992fba3ac6d21bbd":[15,12,2,5,1],
+"group__struct__utils__deprecated.html#ga07b7e90e712559a1992fba3ac6d21bbd":[17,0,0,81,0],
+"group__struct__utils__deprecated.html#ga09a80253ac7b6bae606871ba7c6e5136":[17,0,0,81,7],
+"group__struct__utils__deprecated.html#ga09a80253ac7b6bae606871ba7c6e5136":[15,12,2,5,8],
+"group__struct__utils__deprecated.html#ga1054c4477d53b31d79d4cb132100e87a":[17,0,0,81,8],
+"group__struct__utils__deprecated.html#ga1054c4477d53b31d79d4cb132100e87a":[15,12,2,5,9],
+"group__struct__utils__deprecated.html#ga129d81c4a1ead793c5b2311333e03dfa":[15,12,2,5,22],
+"group__struct__utils__deprecated.html#ga129d81c4a1ead793c5b2311333e03dfa":[17,0,0,8,5,64],
+"group__struct__utils__deprecated.html#ga260c4b622093b76a883bf96628280de1":[15,12,2,5,7],
+"group__struct__utils__deprecated.html#ga260c4b622093b76a883bf96628280de1":[17,0,0,81,6],
+"group__struct__utils__deprecated.html#ga365a3fad38b21ca8606cb556f2896218":[15,12,2,5,24]
 };
