@@ -1,101 +1,81 @@
 var NAVTREEINDEX9 =
 {
-"group__struct__utils.html#ga65bdfbac6a16bf30286e8a3f7d15f60a":[15,12,2,8],
-"group__struct__utils.html#ga65bdfbac6a16bf30286e8a3f7d15f60a":[17,0,0,8,5,42],
-"group__struct__utils.html#gab4c2a00c99ce1d612ffa5bde114eb96d":[15,12,2,9],
-"group__struct__utils.html#gab4c2a00c99ce1d612ffa5bde114eb96d":[17,0,0,8,5,43],
-"group__struct__utils__deprecated.html":[15,12,2,5],
-"group__struct__utils__deprecated.html#ga0518a287aa4a870508cea819029778ab":[15,12,2,5,26],
-"group__struct__utils__deprecated.html#ga0518a287aa4a870508cea819029778ab":[17,0,0,80,12],
-"group__struct__utils__deprecated.html#ga071c6921efe1eb974f115ee6fefa3c39":[17,0,0,8,5,53],
-"group__struct__utils__deprecated.html#ga071c6921efe1eb974f115ee6fefa3c39":[15,12,2,5,12],
-"group__struct__utils__deprecated.html#ga07b7e90e712559a1992fba3ac6d21bbd":[15,12,2,5,1],
-"group__struct__utils__deprecated.html#ga07b7e90e712559a1992fba3ac6d21bbd":[17,0,0,80,0],
-"group__struct__utils__deprecated.html#ga09a80253ac7b6bae606871ba7c6e5136":[17,0,0,80,7],
-"group__struct__utils__deprecated.html#ga09a80253ac7b6bae606871ba7c6e5136":[15,12,2,5,8],
-"group__struct__utils__deprecated.html#ga1054c4477d53b31d79d4cb132100e87a":[17,0,0,80,8],
-"group__struct__utils__deprecated.html#ga1054c4477d53b31d79d4cb132100e87a":[15,12,2,5,9],
-"group__struct__utils__deprecated.html#ga129d81c4a1ead793c5b2311333e03dfa":[15,12,2,5,22],
-"group__struct__utils__deprecated.html#ga129d81c4a1ead793c5b2311333e03dfa":[17,0,0,8,5,64],
-"group__struct__utils__deprecated.html#ga260c4b622093b76a883bf96628280de1":[15,12,2,5,7],
-"group__struct__utils__deprecated.html#ga260c4b622093b76a883bf96628280de1":[17,0,0,80,6],
-"group__struct__utils__deprecated.html#ga365a3fad38b21ca8606cb556f2896218":[15,12,2,5,24],
-"group__struct__utils__deprecated.html#ga365a3fad38b21ca8606cb556f2896218":[17,0,0,80,10],
-"group__struct__utils__deprecated.html#ga3c79042e6bf6f01706bf30ec9e69e8ac":[17,0,0,80,9],
+"group__struct__utils__deprecated.html#ga365a3fad38b21ca8606cb556f2896218":[17,0,0,81,10],
+"group__struct__utils__deprecated.html#ga3c79042e6bf6f01706bf30ec9e69e8ac":[17,0,0,81,9],
 "group__struct__utils__deprecated.html#ga3c79042e6bf6f01706bf30ec9e69e8ac":[15,12,2,5,10],
-"group__struct__utils__deprecated.html#ga3c81b3967056c3888b8472b65fbb16f5":[17,0,0,8,5,56],
 "group__struct__utils__deprecated.html#ga3c81b3967056c3888b8472b65fbb16f5":[15,12,2,5,15],
+"group__struct__utils__deprecated.html#ga3c81b3967056c3888b8472b65fbb16f5":[17,0,0,8,5,56],
 "group__struct__utils__deprecated.html#ga3fce53616c021cbc724fc80b8c1ebeb5":[15,12,2,5,25],
-"group__struct__utils__deprecated.html#ga3fce53616c021cbc724fc80b8c1ebeb5":[17,0,0,80,11],
-"group__struct__utils__deprecated.html#ga439fcb9f8d4f9f4d2227fde5fbfecb30":[17,0,0,80,13],
+"group__struct__utils__deprecated.html#ga3fce53616c021cbc724fc80b8c1ebeb5":[17,0,0,81,11],
 "group__struct__utils__deprecated.html#ga439fcb9f8d4f9f4d2227fde5fbfecb30":[15,12,2,5,27],
-"group__struct__utils__deprecated.html#ga49962ad6242b8c628de6ca16bb831c1d":[15,12,2,5,23],
+"group__struct__utils__deprecated.html#ga439fcb9f8d4f9f4d2227fde5fbfecb30":[17,0,0,81,13],
 "group__struct__utils__deprecated.html#ga49962ad6242b8c628de6ca16bb831c1d":[17,0,0,8,5,65],
-"group__struct__utils__deprecated.html#ga578cd9712dee812fb1c58aa3cc489864":[17,0,0,8,5,59],
+"group__struct__utils__deprecated.html#ga49962ad6242b8c628de6ca16bb831c1d":[15,12,2,5,23],
 "group__struct__utils__deprecated.html#ga578cd9712dee812fb1c58aa3cc489864":[15,12,2,5,18],
+"group__struct__utils__deprecated.html#ga578cd9712dee812fb1c58aa3cc489864":[17,0,0,8,5,59],
 "group__struct__utils__deprecated.html#ga5cd2feb367feeacad0c03cb7ddba5f10":[15,12,2,5,3],
-"group__struct__utils__deprecated.html#ga5cd2feb367feeacad0c03cb7ddba5f10":[17,0,0,80,2],
+"group__struct__utils__deprecated.html#ga5cd2feb367feeacad0c03cb7ddba5f10":[17,0,0,81,2],
 "group__struct__utils__deprecated.html#ga6341cbb704924824e0236c1dce791032":[15,12,2,5,29],
-"group__struct__utils__deprecated.html#ga6341cbb704924824e0236c1dce791032":[17,0,0,80,15],
+"group__struct__utils__deprecated.html#ga6341cbb704924824e0236c1dce791032":[17,0,0,81,15],
 "group__struct__utils__deprecated.html#ga6ebbcd29a754f0e4f1a66d1fd84184db":[15,12,2,5,17],
 "group__struct__utils__deprecated.html#ga6ebbcd29a754f0e4f1a66d1fd84184db":[17,0,0,8,5,58],
+"group__struct__utils__deprecated.html#ga78d73cd54a068ef2812812771cdddc6f":[17,0,0,81,5],
 "group__struct__utils__deprecated.html#ga78d73cd54a068ef2812812771cdddc6f":[15,12,2,5,6],
-"group__struct__utils__deprecated.html#ga78d73cd54a068ef2812812771cdddc6f":[17,0,0,80,5],
 "group__struct__utils__deprecated.html#ga880d33066dd95441e5fbb73c57ed1c3e":[15,12,2,5,4],
-"group__struct__utils__deprecated.html#ga880d33066dd95441e5fbb73c57ed1c3e":[17,0,0,80,3],
-"group__struct__utils__deprecated.html#ga89c32307ee50a0026f4a3131fac0845a":[17,0,0,8,5,54],
+"group__struct__utils__deprecated.html#ga880d33066dd95441e5fbb73c57ed1c3e":[17,0,0,81,3],
 "group__struct__utils__deprecated.html#ga89c32307ee50a0026f4a3131fac0845a":[15,12,2,5,13],
+"group__struct__utils__deprecated.html#ga89c32307ee50a0026f4a3131fac0845a":[17,0,0,8,5,54],
 "group__struct__utils__deprecated.html#ga9aa3bf3b4346bb7fb88efc154dd07a79":[15,12,2,5,16],
 "group__struct__utils__deprecated.html#ga9aa3bf3b4346bb7fb88efc154dd07a79":[17,0,0,8,5,57],
-"group__struct__utils__deprecated.html#ga9c80d92391f2833549a8b6dac92233f0":[17,0,0,80,1],
 "group__struct__utils__deprecated.html#ga9c80d92391f2833549a8b6dac92233f0":[15,12,2,5,2],
+"group__struct__utils__deprecated.html#ga9c80d92391f2833549a8b6dac92233f0":[17,0,0,81,1],
 "group__struct__utils__deprecated.html#gab9c5c8311bd5120900585d4fa50c2df0":[15,12,2,5,21],
 "group__struct__utils__deprecated.html#gab9c5c8311bd5120900585d4fa50c2df0":[17,0,0,8,5,63],
+"group__struct__utils__deprecated.html#gabe3d815b420dc4553bfb23511198b4c6":[17,0,0,81,4],
 "group__struct__utils__deprecated.html#gabe3d815b420dc4553bfb23511198b4c6":[15,12,2,5,5],
-"group__struct__utils__deprecated.html#gabe3d815b420dc4553bfb23511198b4c6":[17,0,0,80,4],
 "group__struct__utils__deprecated.html#gac6dfa5e22928c087c6e09ff0054a7ced":[15,12,2,5,11],
 "group__struct__utils__deprecated.html#gac6dfa5e22928c087c6e09ff0054a7ced":[17,0,0,8,5,52],
-"group__struct__utils__deprecated.html#gadd2f952597e02d66e1116a9d11d252d6":[17,0,0,80,14],
+"group__struct__utils__deprecated.html#gadd2f952597e02d66e1116a9d11d252d6":[17,0,0,81,14],
 "group__struct__utils__deprecated.html#gadd2f952597e02d66e1116a9d11d252d6":[15,12,2,5,28],
 "group__struct__utils__deprecated.html#gadd463184355d0803b6ee6e09f29182f2":[15,12,2,5,19],
 "group__struct__utils__deprecated.html#gadd463184355d0803b6ee6e09f29182f2":[17,0,0,8,5,60],
 "group__struct__utils__deprecated.html#gadf0ad2d46c9ca7b850437d1b79627a7e":[15,12,2,5,20],
 "group__struct__utils__deprecated.html#gadf0ad2d46c9ca7b850437d1b79627a7e":[17,0,0,8,5,62],
-"group__struct__utils__deprecated.html#gafeaa6d68eef3a99d0a7aa08aa91c6601":[17,0,0,8,5,55],
 "group__struct__utils__deprecated.html#gafeaa6d68eef3a99d0a7aa08aa91c6601":[15,12,2,5,14],
+"group__struct__utils__deprecated.html#gafeaa6d68eef3a99d0a7aa08aa91c6601":[17,0,0,8,5,55],
 "group__struct__utils__dot__bracket.html":[15,12,2,0],
 "group__struct__utils__dot__bracket.html#ga013a9da903462d2f2b037f0c6ffb46e4":[15,12,2,0,6],
 "group__struct__utils__dot__bracket.html#ga013a9da903462d2f2b037f0c6ffb46e4":[17,0,0,8,5,6],
-"group__struct__utils__dot__bracket.html#ga02ca70cffb2d864f7b2d95d92218bae0":[15,12,2,0,12],
 "group__struct__utils__dot__bracket.html#ga02ca70cffb2d864f7b2d95d92218bae0":[17,0,0,8,5,26],
-"group__struct__utils__dot__bracket.html#ga45360c09fb6d04d96e42dcccbb66015b":[15,12,2,0,14],
+"group__struct__utils__dot__bracket.html#ga02ca70cffb2d864f7b2d95d92218bae0":[15,12,2,0,12],
 "group__struct__utils__dot__bracket.html#ga45360c09fb6d04d96e42dcccbb66015b":[17,0,0,8,5,28],
-"group__struct__utils__dot__bracket.html#ga559ebf76b1b289f85309f4206e99aa1a":[17,0,0,8,5,5],
+"group__struct__utils__dot__bracket.html#ga45360c09fb6d04d96e42dcccbb66015b":[15,12,2,0,14],
 "group__struct__utils__dot__bracket.html#ga559ebf76b1b289f85309f4206e99aa1a":[15,12,2,0,5],
+"group__struct__utils__dot__bracket.html#ga559ebf76b1b289f85309f4206e99aa1a":[17,0,0,8,5,5],
 "group__struct__utils__dot__bracket.html#ga55c4783060a1464f862f858d5599c9e1":[15,12,2,0,7],
 "group__struct__utils__dot__bracket.html#ga55c4783060a1464f862f858d5599c9e1":[17,0,0,8,5,21],
-"group__struct__utils__dot__bracket.html#ga60525d61d7496eeea490a37f3d6bf757":[15,12,2,0,4],
 "group__struct__utils__dot__bracket.html#ga60525d61d7496eeea490a37f3d6bf757":[17,0,0,8,5,4],
-"group__struct__utils__dot__bracket.html#ga6490adff857d84ce06e6f379ae3a4512":[15,12,2,0,8],
+"group__struct__utils__dot__bracket.html#ga60525d61d7496eeea490a37f3d6bf757":[15,12,2,0,4],
 "group__struct__utils__dot__bracket.html#ga6490adff857d84ce06e6f379ae3a4512":[17,0,0,8,5,22],
+"group__struct__utils__dot__bracket.html#ga6490adff857d84ce06e6f379ae3a4512":[15,12,2,0,8],
 "group__struct__utils__dot__bracket.html#ga690425199c8b71545e7196e3af1436f8":[17,0,0,8,5,24],
 "group__struct__utils__dot__bracket.html#ga690425199c8b71545e7196e3af1436f8":[15,12,2,0,10],
-"group__struct__utils__dot__bracket.html#ga6a51a36b9245d0bac868c5cd172b9611":[17,0,0,8,5,27],
 "group__struct__utils__dot__bracket.html#ga6a51a36b9245d0bac868c5cd172b9611":[15,12,2,0,13],
-"group__struct__utils__dot__bracket.html#ga7e3f630af8d69bb0e917145aacf2f96d":[17,0,0,8,5,0],
+"group__struct__utils__dot__bracket.html#ga6a51a36b9245d0bac868c5cd172b9611":[17,0,0,8,5,27],
 "group__struct__utils__dot__bracket.html#ga7e3f630af8d69bb0e917145aacf2f96d":[15,12,2,0,0],
+"group__struct__utils__dot__bracket.html#ga7e3f630af8d69bb0e917145aacf2f96d":[17,0,0,8,5,0],
 "group__struct__utils__dot__bracket.html#ga863e03f7f73f10fc9bbcbefbdda4bec8":[15,12,2,0,3],
 "group__struct__utils__dot__bracket.html#ga863e03f7f73f10fc9bbcbefbdda4bec8":[17,0,0,8,5,3],
-"group__struct__utils__dot__bracket.html#ga97dbebaa3fc49524cf5afa338a6c52ee":[15,12,2,0,15],
 "group__struct__utils__dot__bracket.html#ga97dbebaa3fc49524cf5afa338a6c52ee":[17,0,0,8,5,29],
-"group__struct__utils__dot__bracket.html#gac92d5fa7c6625bce2670ece510a24fbd":[15,12,2,0,1],
+"group__struct__utils__dot__bracket.html#ga97dbebaa3fc49524cf5afa338a6c52ee":[15,12,2,0,15],
 "group__struct__utils__dot__bracket.html#gac92d5fa7c6625bce2670ece510a24fbd":[17,0,0,8,5,1],
-"group__struct__utils__dot__bracket.html#gaf41be40e79cb756c4e0bb8edb4d803d2":[17,0,0,8,5,2],
+"group__struct__utils__dot__bracket.html#gac92d5fa7c6625bce2670ece510a24fbd":[15,12,2,0,1],
 "group__struct__utils__dot__bracket.html#gaf41be40e79cb756c4e0bb8edb4d803d2":[15,12,2,0,2],
-"group__struct__utils__dot__bracket.html#gaf9ecd0d7877fecdbb0292e24f40283d5":[17,0,0,8,5,25],
+"group__struct__utils__dot__bracket.html#gaf41be40e79cb756c4e0bb8edb4d803d2":[17,0,0,8,5,2],
 "group__struct__utils__dot__bracket.html#gaf9ecd0d7877fecdbb0292e24f40283d5":[15,12,2,0,11],
-"group__struct__utils__dot__bracket.html#gafd1304f5a86e2e3f1425e725cde44fa2":[17,0,0,8,5,23],
+"group__struct__utils__dot__bracket.html#gaf9ecd0d7877fecdbb0292e24f40283d5":[17,0,0,8,5,25],
 "group__struct__utils__dot__bracket.html#gafd1304f5a86e2e3f1425e725cde44fa2":[15,12,2,0,9],
+"group__struct__utils__dot__bracket.html#gafd1304f5a86e2e3f1425e725cde44fa2":[17,0,0,8,5,23],
 "group__struct__utils__helix__list.html":[15,12,2,3],
 "group__struct__utils__helix__list.html#ga2fdaac8bb6c239c119ad5c20b145b7f2":[15,12,2,3,3],
 "group__struct__utils__helix__list.html#ga2fdaac8bb6c239c119ad5c20b145b7f2":[17,0,0,8,5,40],
@@ -107,16 +87,16 @@ var NAVTREEINDEX9 =
 "group__struct__utils__pair__table.html":[15,12,2,1],
 "group__struct__utils__pair__table.html#ga1ee4cdcda1f57d32dcb38032116d335d":[15,12,2,1,4],
 "group__struct__utils__pair__table.html#ga1ee4cdcda1f57d32dcb38032116d335d":[17,0,0,8,5,34],
-"group__struct__utils__pair__table.html#ga2daefbbd6d9f8803731651882f54332d":[15,12,2,1,3],
 "group__struct__utils__pair__table.html#ga2daefbbd6d9f8803731651882f54332d":[17,0,0,8,5,33],
-"group__struct__utils__pair__table.html#gac76c9ef3de507748fb0416a59323362b":[17,0,0,8,5,31],
+"group__struct__utils__pair__table.html#ga2daefbbd6d9f8803731651882f54332d":[15,12,2,1,3],
 "group__struct__utils__pair__table.html#gac76c9ef3de507748fb0416a59323362b":[15,12,2,1,1],
+"group__struct__utils__pair__table.html#gac76c9ef3de507748fb0416a59323362b":[17,0,0,8,5,31],
 "group__struct__utils__pair__table.html#gacca520048b24ec5a8978f4dafb4e4bf8":[15,12,2,1,2],
 "group__struct__utils__pair__table.html#gacca520048b24ec5a8978f4dafb4e4bf8":[17,0,0,8,5,32],
-"group__struct__utils__pair__table.html#gae829fb8bb7f694c12a9c0bbc34c77c60":[17,0,0,8,5,30],
 "group__struct__utils__pair__table.html#gae829fb8bb7f694c12a9c0bbc34c77c60":[15,12,2,1,0],
-"group__struct__utils__pair__table.html#gae8f31c859b48f97b8af889e914e4d040":[17,0,0,8,5,36],
+"group__struct__utils__pair__table.html#gae829fb8bb7f694c12a9c0bbc34c77c60":[17,0,0,8,5,30],
 "group__struct__utils__pair__table.html#gae8f31c859b48f97b8af889e914e4d040":[15,12,2,1,6],
+"group__struct__utils__pair__table.html#gae8f31c859b48f97b8af889e914e4d040":[17,0,0,8,5,36],
 "group__struct__utils__pair__table.html#gaef0f7e1a6c00c81a349973de53039dda":[15,12,2,1,5],
 "group__struct__utils__pair__table.html#gaef0f7e1a6c00c81a349973de53039dda":[17,0,0,8,5,35],
 "group__struct__utils__plist.html":[15,12,2,2],
@@ -148,44 +128,44 @@ var NAVTREEINDEX9 =
 "group__struct__utils__tree.html#ga4acd9991a0250ccd4cd44c4725b31927":[17,0,0,8,5,15],
 "group__struct__utils__tree.html#ga549e259a963d77e2d5b7e14083fc016e":[15,12,2,4,1],
 "group__struct__utils__tree.html#ga549e259a963d77e2d5b7e14083fc016e":[17,0,0,8,5,14],
-"group__struct__utils__tree.html#ga56551ab7da64933a7230d29430f40cfe":[17,0,0,8,5,48],
 "group__struct__utils__tree.html#ga56551ab7da64933a7230d29430f40cfe":[15,12,2,4,6],
-"group__struct__utils__tree.html#ga8666a10982a4f7a26892066ff07b4b48":[15,12,2,4,3],
+"group__struct__utils__tree.html#ga56551ab7da64933a7230d29430f40cfe":[17,0,0,8,5,48],
 "group__struct__utils__tree.html#ga8666a10982a4f7a26892066ff07b4b48":[17,0,0,8,5,16],
-"group__struct__utils__tree.html#ga91f2e3a3a502d5445fd7fe5983a5fe92":[15,12,2,4,4],
+"group__struct__utils__tree.html#ga8666a10982a4f7a26892066ff07b4b48":[15,12,2,4,3],
 "group__struct__utils__tree.html#ga91f2e3a3a502d5445fd7fe5983a5fe92":[17,0,0,8,5,17],
+"group__struct__utils__tree.html#ga91f2e3a3a502d5445fd7fe5983a5fe92":[15,12,2,4,4],
 "group__struct__utils__tree.html#ga99d280319a7fd3f87e9f0d8c44520774":[15,12,2,4,8],
 "group__struct__utils__tree.html#ga99d280319a7fd3f87e9f0d8c44520774":[17,0,0,8,5,50],
-"group__struct__utils__tree.html#gaa31da26a3f582ddc35a84ff1b9c0a2b0":[17,0,0,8,5,49],
 "group__struct__utils__tree.html#gaa31da26a3f582ddc35a84ff1b9c0a2b0":[15,12,2,4,7],
-"group__struct__utils__tree.html#gab3b65489d1322da65d3a3e53242307ef":[15,12,2,4,5],
+"group__struct__utils__tree.html#gaa31da26a3f582ddc35a84ff1b9c0a2b0":[17,0,0,8,5,49],
 "group__struct__utils__tree.html#gab3b65489d1322da65d3a3e53242307ef":[17,0,0,8,5,18],
+"group__struct__utils__tree.html#gab3b65489d1322da65d3a3e53242307ef":[15,12,2,4,5],
 "group__subopt__and__representatives.html":[15,5],
 "group__subopt__stochbt.html":[15,5,2],
 "group__subopt__stochbt.html#ga30c3ddff868c44eecfdb07d99a2422ba":[17,0,0,15,5],
 "group__subopt__stochbt.html#ga30c3ddff868c44eecfdb07d99a2422ba":[15,5,2,7],
-"group__subopt__stochbt.html#ga4a91dc092580faf7799476e8dd76e0ac":[15,5,2,10],
 "group__subopt__stochbt.html#ga4a91dc092580faf7799476e8dd76e0ac":[17,0,0,15,8],
+"group__subopt__stochbt.html#ga4a91dc092580faf7799476e8dd76e0ac":[15,5,2,10],
 "group__subopt__stochbt.html#ga594844ac73c4e66e00d6791b31540634":[17,0,0,15,9],
 "group__subopt__stochbt.html#ga594844ac73c4e66e00d6791b31540634":[15,5,2,11],
-"group__subopt__stochbt.html#ga596ed9bcd86f629a7c7c59c58b297db5":[17,0,0,15,10],
 "group__subopt__stochbt.html#ga596ed9bcd86f629a7c7c59c58b297db5":[15,5,2,12],
-"group__subopt__stochbt.html#ga626beb5b5b962d7e7c8433cd2cfd4e93":[15,5,2,8],
+"group__subopt__stochbt.html#ga596ed9bcd86f629a7c7c59c58b297db5":[17,0,0,15,10],
 "group__subopt__stochbt.html#ga626beb5b5b962d7e7c8433cd2cfd4e93":[17,0,0,15,6],
+"group__subopt__stochbt.html#ga626beb5b5b962d7e7c8433cd2cfd4e93":[15,5,2,8],
 "group__subopt__stochbt.html#ga6fc5ce952995e53baef52cad5581c063":[17,0,0,15,13],
 "group__subopt__stochbt.html#ga6fc5ce952995e53baef52cad5581c063":[15,5,2,15],
-"group__subopt__stochbt.html#ga72ebbe45bcbce147a12f27f62b38db78":[17,0,0,15,4],
 "group__subopt__stochbt.html#ga72ebbe45bcbce147a12f27f62b38db78":[15,5,2,6],
+"group__subopt__stochbt.html#ga72ebbe45bcbce147a12f27f62b38db78":[17,0,0,15,4],
 "group__subopt__stochbt.html#ga760aa2fb2d5e3d7521a11454a21e9b9f":[17,0,0,15,0],
 "group__subopt__stochbt.html#ga760aa2fb2d5e3d7521a11454a21e9b9f":[15,5,2,2],
-"group__subopt__stochbt.html#ga843fa953a15337b15cc68401adad84d7":[17,0,0,15,11],
 "group__subopt__stochbt.html#ga843fa953a15337b15cc68401adad84d7":[15,5,2,13],
+"group__subopt__stochbt.html#ga843fa953a15337b15cc68401adad84d7":[17,0,0,15,11],
 "group__subopt__stochbt.html#ga9d580ce645aa0c38b69afdf56c332200":[17,0,0,15,1],
 "group__subopt__stochbt.html#ga9d580ce645aa0c38b69afdf56c332200":[15,5,2,3],
-"group__subopt__stochbt.html#gaa59c30efbed96bf9aaf8005584c72e63":[15,5,2,5],
 "group__subopt__stochbt.html#gaa59c30efbed96bf9aaf8005584c72e63":[17,0,0,15,3],
-"group__subopt__stochbt.html#gac5d7065196975b803daeb4e094ba1cb9":[17,0,0,15,7],
+"group__subopt__stochbt.html#gaa59c30efbed96bf9aaf8005584c72e63":[15,5,2,5],
 "group__subopt__stochbt.html#gac5d7065196975b803daeb4e094ba1cb9":[15,5,2,9],
+"group__subopt__stochbt.html#gac5d7065196975b803daeb4e094ba1cb9":[17,0,0,15,7],
 "group__subopt__stochbt.html#gad5bd9c8b195dd9cde15389f0042f0e44":[17,0,0,15,2],
 "group__subopt__stochbt.html#gad5bd9c8b195dd9cde15389f0042f0e44":[15,5,2,4],
 "group__subopt__stochbt.html#gae175129ece546fe7c092f27072e039d1":[17,0,0,15,12],
@@ -193,61 +173,81 @@ var NAVTREEINDEX9 =
 "group__subopt__stochbt.html#gae64fbdef59e7f503d7e920aac279212b":[17,0,0,15,14],
 "group__subopt__stochbt.html#gae64fbdef59e7f503d7e920aac279212b":[15,5,2,16],
 "group__subopt__stochbt__deprecated.html":[15,5,2,1],
-"group__subopt__stochbt__deprecated.html#ga00474051204ac9ad576b3e45174d03ff":[17,0,0,64,15],
+"group__subopt__stochbt__deprecated.html#ga00474051204ac9ad576b3e45174d03ff":[17,0,0,65,15],
 "group__subopt__stochbt__deprecated.html#ga00474051204ac9ad576b3e45174d03ff":[15,5,2,1,2],
+"group__subopt__stochbt__deprecated.html#gac03ca6db186bb3bf0a2a326d7fb3ba03":[17,0,0,65,13],
 "group__subopt__stochbt__deprecated.html#gac03ca6db186bb3bf0a2a326d7fb3ba03":[15,5,2,1,0],
-"group__subopt__stochbt__deprecated.html#gac03ca6db186bb3bf0a2a326d7fb3ba03":[17,0,0,64,13],
 "group__subopt__stochbt__deprecated.html#gacd79b1a570e6ad9be24cb11fe8cae30a":[15,5,2,1,3],
-"group__subopt__stochbt__deprecated.html#gacd79b1a570e6ad9be24cb11fe8cae30a":[17,0,0,64,31],
-"group__subopt__stochbt__deprecated.html#gaf2e614b8beb4ddf3e8751433b76f39db":[17,0,0,64,14],
+"group__subopt__stochbt__deprecated.html#gacd79b1a570e6ad9be24cb11fe8cae30a":[17,0,0,65,31],
+"group__subopt__stochbt__deprecated.html#gaf2e614b8beb4ddf3e8751433b76f39db":[17,0,0,65,14],
 "group__subopt__stochbt__deprecated.html#gaf2e614b8beb4ddf3e8751433b76f39db":[15,5,2,1,1],
 "group__subopt__wuchty.html":[15,5,1],
-"group__subopt__wuchty.html#ga0f11d738fb8c8b1885a90c11c8931ff6":[17,0,0,90,5],
+"group__subopt__wuchty.html#ga0f11d738fb8c8b1885a90c11c8931ff6":[17,0,0,91,5],
 "group__subopt__wuchty.html#ga0f11d738fb8c8b1885a90c11c8931ff6":[15,5,1,1],
+"group__subopt__wuchty.html#ga1053837e6b6f158093508f8a70998352":[17,0,0,91,6],
 "group__subopt__wuchty.html#ga1053837e6b6f158093508f8a70998352":[15,5,1,2],
-"group__subopt__wuchty.html#ga1053837e6b6f158093508f8a70998352":[17,0,0,90,6],
-"group__subopt__wuchty.html#ga5e57d914bcb5feeecdf520e25313fcfe":[17,0,0,90,13],
+"group__subopt__wuchty.html#ga5e57d914bcb5feeecdf520e25313fcfe":[17,0,0,91,13],
 "group__subopt__wuchty.html#ga5e57d914bcb5feeecdf520e25313fcfe":[15,5,1,6],
-"group__subopt__wuchty.html#ga700f662506a233e42dd7fda74fafd40e":[17,0,0,90,8],
 "group__subopt__wuchty.html#ga700f662506a233e42dd7fda74fafd40e":[15,5,1,3],
-"group__subopt__wuchty.html#ga8634516e4740e0b6c9a46d2bae940340":[17,0,0,90,10],
+"group__subopt__wuchty.html#ga700f662506a233e42dd7fda74fafd40e":[17,0,0,91,8],
+"group__subopt__wuchty.html#ga8634516e4740e0b6c9a46d2bae940340":[17,0,0,91,10],
 "group__subopt__wuchty.html#ga8634516e4740e0b6c9a46d2bae940340":[15,5,1,5],
-"group__subopt__wuchty.html#ga873cf8ed69e0437f8efa8b1fec854a0e":[17,0,0,90,14],
+"group__subopt__wuchty.html#ga873cf8ed69e0437f8efa8b1fec854a0e":[17,0,0,91,14],
 "group__subopt__wuchty.html#ga873cf8ed69e0437f8efa8b1fec854a0e":[15,5,1,7],
+"group__subopt__wuchty.html#gaa0270c66d04f59e750401695b8282e04":[17,0,0,91,3],
 "group__subopt__wuchty.html#gaa0270c66d04f59e750401695b8282e04":[15,5,1,0],
-"group__subopt__wuchty.html#gaa0270c66d04f59e750401695b8282e04":[17,0,0,90,3],
-"group__subopt__wuchty.html#gaa1e1e7031a948ebcb39a9d58d1e9842c":[17,0,0,90,9],
 "group__subopt__wuchty.html#gaa1e1e7031a948ebcb39a9d58d1e9842c":[15,5,1,4],
+"group__subopt__wuchty.html#gaa1e1e7031a948ebcb39a9d58d1e9842c":[17,0,0,91,9],
 "group__subopt__zuker.html":[15,5,0],
-"group__subopt__zuker.html#ga0d5104e3ecf119d8eabd40aa5fe47f90":[17,0,0,90,11],
+"group__subopt__zuker.html#ga0d5104e3ecf119d8eabd40aa5fe47f90":[17,0,0,91,11],
 "group__subopt__zuker.html#ga0d5104e3ecf119d8eabd40aa5fe47f90":[15,5,0,1],
-"group__subopt__zuker.html#gab6d0ea8cc1d02f6dd831ca81043c9eb8":[17,0,0,90,12],
 "group__subopt__zuker.html#gab6d0ea8cc1d02f6dd831ca81043c9eb8":[15,5,0,2],
-"group__subopt__zuker.html#gababde9d210eb433854f1e71da7815fbb":[17,0,0,90,7],
+"group__subopt__zuker.html#gab6d0ea8cc1d02f6dd831ca81043c9eb8":[17,0,0,91,12],
 "group__subopt__zuker.html#gababde9d210eb433854f1e71da7815fbb":[15,5,0,0],
+"group__subopt__zuker.html#gababde9d210eb433854f1e71da7815fbb":[17,0,0,91,7],
+"group__thermodynamics.html":[15,4,0,1],
+"group__thermodynamics.html#a2987d5e5ef974d14a108ec1c7062562f":[15,4,0,1,2,1],
+"group__thermodynamics.html#a62ed3466ce614f4f1e729463fac41d72":[15,4,0,1,2,0],
+"group__thermodynamics.html#ga0c2664e15dded704d805a9d2a625ff21":[17,0,0,48,4],
+"group__thermodynamics.html#ga0c2664e15dded704d805a9d2a625ff21":[15,4,0,1,15],
+"group__thermodynamics.html#ga132664bf29fdc30bb5ea715491d1ab22":[17,0,0,35,4],
+"group__thermodynamics.html#ga132664bf29fdc30bb5ea715491d1ab22":[15,4,0,1,9],
+"group__thermodynamics.html#ga18316e4657502e9203931f924d93732f":[17,0,0,48,0],
+"group__thermodynamics.html#ga18316e4657502e9203931f924d93732f":[15,4,0,1,3],
+"group__thermodynamics.html#ga4ec346141028c7bcd15bc235c408b6e9":[17,0,0,35,3],
+"group__thermodynamics.html#ga4ec346141028c7bcd15bc235c408b6e9":[15,4,0,1,8],
+"group__thermodynamics.html#ga882c35d9dd775c1275593b3b6a966bec":[17,0,0,35,6],
+"group__thermodynamics.html#ga882c35d9dd775c1275593b3b6a966bec":[15,4,0,1,11],
+"group__thermodynamics.html#ga99dc703d840310177ecf7aedf72b4409":[15,4,0,1,4],
+"group__thermodynamics.html#ga99dc703d840310177ecf7aedf72b4409":[17,0,0,48,1],
+"group__thermodynamics.html#gaa1e39e73afb51fbaf4ae38f0c066c46b":[15,4,0,1,10],
+"group__thermodynamics.html#gaa1e39e73afb51fbaf4ae38f0c066c46b":[17,0,0,35,5],
+"group__thermodynamics.html#gaa6b8983b559b9ef4b2e1b31113ea317b":[17,0,0,35,1],
+"group__thermodynamics.html#gaa6b8983b559b9ef4b2e1b31113ea317b":[15,4,0,1,6],
+"group__thermodynamics.html#gaa88e17336daede0e6db4da1f3252c031":[17,0,0,35,7],
+"group__thermodynamics.html#gaa88e17336daede0e6db4da1f3252c031":[15,4,0,1,12],
+"group__thermodynamics.html#gaaf197722d1faa86af5e7b4240acafdee":[17,0,0,35,2],
+"group__thermodynamics.html#gaaf197722d1faa86af5e7b4240acafdee":[15,4,0,1,7],
+"group__thermodynamics.html#gaca54de116562d187484e3fa884aeb52c":[15,4,0,1,14],
+"group__thermodynamics.html#gaca54de116562d187484e3fa884aeb52c":[17,0,0,48,3],
+"group__thermodynamics.html#gad3f0c240512e6d43e2e4d4c2076021f5":[17,0,0,35,0],
+"group__thermodynamics.html#gad3f0c240512e6d43e2e4d4c2076021f5":[15,4,0,1,5],
+"group__thermodynamics.html#gafd95c2350d67d8f4374369c19cf111f1":[17,0,0,48,2],
+"group__thermodynamics.html#gafd95c2350d67d8f4374369c19cf111f1":[15,4,0,1,13],
+"group__thermodynamics.html#structvrna__heat__capacity__s":[15,4,0,1,2],
 "group__units.html":[15,12,10],
+"group__units.html#ga085428efe4f99044bce8273c8b5db1ba":[15,12,10,5],
+"group__units.html#ga085428efe4f99044bce8273c8b5db1ba":[17,0,0,8,7,4],
 "group__units.html#ga1d2fd1e73caf995e4dc69072b33e6ba5":[15,12,10,1],
-"group__units.html#ga1d2fd1e73caf995e4dc69072b33e6ba5":[17,0,0,94,0],
+"group__units.html#ga1d2fd1e73caf995e4dc69072b33e6ba5":[17,0,0,8,7,0],
+"group__units.html#gada3216e97b410928ba19a4487e5fe6f2":[17,0,0,8,7,2],
 "group__units.html#gada3216e97b410928ba19a4487e5fe6f2":[15,12,10,3],
-"group__units.html#gada3216e97b410928ba19a4487e5fe6f2":[17,0,0,94,2],
-"group__units.html#gadeca8d9e91ef85f1b652cc8aef63d7e4":[17,0,0,94,1],
+"group__units.html#gadeca8d9e91ef85f1b652cc8aef63d7e4":[17,0,0,8,7,1],
 "group__units.html#gadeca8d9e91ef85f1b652cc8aef63d7e4":[15,12,10,2],
+"group__units.html#gadef1b636dd61e48e9ad5ebd0d84fb17e":[15,12,10,6],
+"group__units.html#gadef1b636dd61e48e9ad5ebd0d84fb17e":[17,0,0,8,7,5],
 "group__units.html#gaf1bb1db32eba33b9f306214f5955d0c2":[15,12,10,4],
-"group__units.html#gaf1bb1db32eba33b9f306214f5955d0c2":[17,0,0,94,3],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a0120f465758c5d3f0c416bb6b68ac008":[17,0,0,94,0,0],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a0120f465758c5d3f0c416bb6b68ac008":[15,12,10,1,0],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a16f8d3c98e6baf1662c33f082e50e3aa":[17,0,0,94,0,3],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a16f8d3c98e6baf1662c33f082e50e3aa":[15,12,10,1,3],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a32711a912cf18203c635a49ccf104a7a":[15,12,10,1,9],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a32711a912cf18203c635a49ccf104a7a":[17,0,0,94,0,9],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a40325b8627e91b92dc5481961e2193d5":[15,12,10,1,8],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a40325b8627e91b92dc5481961e2193d5":[17,0,0,94,0,8],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a5186dbc0bc2a6fcce080753389e2759c":[17,0,0,94,0,10],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a5186dbc0bc2a6fcce080753389e2759c":[15,12,10,1,10],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a579ddb9fef9ec4b1a198b556715b549c":[17,0,0,94,0,6],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a579ddb9fef9ec4b1a198b556715b549c":[15,12,10,1,6],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a57b033a1f079079cac03c0866ab69ec9":[15,12,10,1,13],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a57b033a1f079079cac03c0866ab69ec9":[17,0,0,94,0,13],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a5a231fa4f1f62a1d6e5f9af020014b79":[17,0,0,94,0,7],
-"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a5a231fa4f1f62a1d6e5f9af020014b79":[15,12,10,1,7]
+"group__units.html#gaf1bb1db32eba33b9f306214f5955d0c2":[17,0,0,8,7,3],
+"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a0120f465758c5d3f0c416bb6b68ac008":[17,0,0,8,7,0,0],
+"group__units.html#gga1d2fd1e73caf995e4dc69072b33e6ba5a0120f465758c5d3f0c416bb6b68ac008":[15,12,10,1,0]
 };
